From: "Michał Grzelak" <michal.grzelak@intel.com>
To: intel-gfx@lists.freedesktop.org
Cc: Thasleem@freedesktop.org, Mohammed <mohammed.thasleem@intel.com>,
"Michał Grzelak" <michal.grzelak@intel.com>
Subject: [RESEND i-g-t v1] tests/kms_flip: test suspend on one pair of pipes
Date: Sun, 1 Feb 2026 16:03:33 +0100 [thread overview]
Message-ID: <20260201150333.2650279-1-michal.grzelak@intel.com> (raw)
Currently, every pair of ({pipe1, pipe2}, {output1, output2}) is being
tested in 2x-* subtests. Since suspend shouldn't be tested per pipe, it
causes unnecessary overhead: with 4 pipes & 4 displays it runs in total
36 tests. Given that each suspend's dynamic subtest can take up to tens
of seconds, total duration of the test easily exceeds timeout.
When testing suspend, for each pair of outputs test only first and last
pipe unless it is said to run on all pipes.
Signed-off-by: Michał Grzelak <michal.grzelak@intel.com>
---
tests/kms_flip.c | 18 ++++++++++++------
1 file changed, 12 insertions(+), 6 deletions(-)
diff --git a/tests/kms_flip.c b/tests/kms_flip.c
index a74e69c6f..dd110aecf 100755
--- a/tests/kms_flip.c
+++ b/tests/kms_flip.c
@@ -1841,8 +1841,8 @@ static void run_test(int duration, int flags)
/* Count output configurations to scale test runtime. */
for (i = 0; i < resources->count_connectors; i++) {
for (n = 0; n < resources->count_crtcs; n++) {
- /* Limit the execution to 2 CRTCs (first & last) for hang tests */
- if ((flags & TEST_HANG) && !all_pipes &&
+ /* Limit the execution to 2 CRTCs (first & last) for hang and suspend tests */
+ if (((flags & TEST_HANG) || (flags & TEST_SUSPEND)) && !all_pipes &&
n != 0 && n != (resources->count_crtcs - 1))
continue;
@@ -1873,8 +1873,8 @@ static void run_test(int duration, int flags)
for (n = 0; n < resources->count_crtcs; n++) {
int crtc_idx;
- /* Limit the execution to 2 CRTCs (first & last) for hang tests */
- if ((flags & TEST_HANG) && !all_pipes &&
+ /* Limit the execution to 2 CRTCs (first & last) for hang and suspend tests */
+ if (((flags & TEST_HANG) || (flags & TEST_SUSPEND)) && !all_pipes &&
n != 0 && n != (resources->count_crtcs - 1))
continue;
@@ -1920,6 +1920,12 @@ static void run_pair(int duration, int flags)
for (n = 0; n < resources->count_crtcs; n++) {
for (j = i + 1; j < resources->count_connectors; j++) {
for (m = n + 1; m < resources->count_crtcs; m++) {
+ /* Limit the execution to 2 CRTCs (first & last) for hang and suspend tests */
+ if (((flags & TEST_HANG) || (flags & TEST_SUSPEND)) && !all_pipes &&
+ ((n != 0 && n != resources->count_crtcs) ||
+ m != resources->count_crtcs - 1))
+ continue;
+
memset(&o, 0, sizeof(o));
o.count = 2;
o._connector[0] = resources->connectors[i];
@@ -1965,8 +1971,8 @@ static void run_pair(int duration, int flags)
crtc_idxs[0] = n;
crtc_idxs[1] = m;
- /* Limit the execution to 2 CRTCs (first & last) for hang tests */
- if ((flags & TEST_HANG) && !all_pipes &&
+ /* Limit the execution to 2 CRTCs (first & last) for hang and suspend tests */
+ if (((flags & TEST_HANG) || (flags & TEST_SUSPEND)) && !all_pipes &&
((n != 0 && n != resources->count_crtcs) ||
m != resources->count_crtcs - 1))
continue;
--
2.45.2
next reply other threads:[~2026-02-01 15:09 UTC|newest]
Thread overview: 2+ messages / expand[flat|nested] mbox.gz Atom feed top
2026-02-01 15:03 Michał Grzelak [this message]
2026-02-03 11:23 ` [RESEND i-g-t v1] tests/kms_flip: test suspend on one pair of pipes Jani Nikula
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20260201150333.2650279-1-michal.grzelak@intel.com \
--to=michal.grzelak@intel.com \
--cc=Thasleem@freedesktop.org \
--cc=intel-gfx@lists.freedesktop.org \
--cc=mohammed.thasleem@intel.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox